← Back to team overview

yade-dev team mailing list archive

[Branch ~yade-dev/yade/trunk] Rev 1727: Some changes on one-click-install script

 

------------------------------------------------------------
revno: 1727
committer: Anton Gladky <gladky.anton@xxxxxxxxx>
branch nick: trunk
timestamp: Mon 2009-08-24 13:51:33 +0200
message:
  Some changes on one-click-install script
modified:
  scripts/installOnUbuntu.sh


--
lp:yade
https://code.launchpad.net/~yade-dev/yade/trunk

Your team Yade developers is subscribed to branch lp:yade.
To unsubscribe from this branch go to https://code.launchpad.net/~yade-dev/yade/trunk/+edit-subscription.
=== modified file 'scripts/installOnUbuntu.sh'
--- scripts/installOnUbuntu.sh	2009-07-24 14:30:47 +0000
+++ scripts/installOnUbuntu.sh	2009-08-24 11:51:33 +0000
@@ -1,22 +1,20 @@
 #!/bin/bash
 # This script works on Ubuntu 9.04, and possibly on new Debians.
 # It "compiles and installs" the latest YADE SVN-version.
 # The install is maximal: you will get almost all YADE functionality, even if you dont need it
 # Please, copy this script to the empty directory and start it.
 # 
 
 
-BASEDIR='./'
+BASEDIR='.'
 VERSION='trunk'
 sudo aptitude install scons libqt3-mt-dev qt3-dev-tools freeglut3-dev libboost-date-time-dev libboost-filesystem-dev libboost-thread-dev libboost-regex-dev fakeroot dpkg-dev build-essential g++ libboost-iostreams-dev liblog4cxx10-dev python-dev libboost-python-dev ipython python-matplotlib libsqlite3-dev python-numeric python-tk gnuplot doxygen python-pygraphviz python-epydoc
-
-svn checkout https://svn.berlios.de/svnroot/repos/yade/trunk
+bzr checkout lp:yade
 mkdir $BASEDIR/build
-mkdir $BASEDIR/data
-cd $BASEDIR/trunk
-scons PREFIX=$BASEDIR/../build optimize=1 -j2 openmp=True features=log4cxx,python,openGL,GTS version=$VERSION
+mkdir $BASEDIR/build/data
+cd $BASEDIR/yade
+scons PREFIX=$BASEDIR/../build optimize=1 -j2 features=log4cxx,python,opengl,gts,openmp version=$VERSION linkStrategy=monolithic
 scons doc
-cd ..
-$BASEDIR/build/bin/yade-$VERSION yade-epydoc.py
-
+cd doc
+$BASEDIR/../../build/bin/yade-$VERSION yade-epydoc.py
@@ -1,22 +1,20 @@
 #!/bin/bash
 # This script works on Ubuntu 9.04, and possibly on new Debians.
-# It "compiles and installs" the latest YADE SVN-version.
+# It "compiles and installs" the latest YADE BZR-version.
 # The install is maximal: you will get almost all YADE functionality, even if you dont need it
 # Please, copy this script to the empty directory and start it.